@@ -859,8 +859,8 @@ void RequestPrivate::_q_onAccessTokenRefreshed() {
     bool ok;
     setResult(QtJson::Json::parse(reply->readAll(), ok));
     
-    QNetworkReply::NetworkError e = reply->error();
-    QString es = reply->errorString();
+    const QNetworkReply::NetworkError e = reply->error();
+    const QString es = reply->errorString();
     reply->deleteLater();
     reply = 0;
     
@@ -942,11 +942,11 @@ void RequestPrivate::_q_onReplyFinished() {
     }
     
     bool ok = true;
-    QString response = QString::fromUtf8(reply->readAll());
+    const QString response = QString::fromUtf8(reply->readAll());
     setResult(response.isEmpty() ? response : QtJson::Json::parse(response, ok));
     
-    QNetworkReply::NetworkError e = reply->error();
-    QString es = reply->errorString();
+    const QNetworkReply::NetworkError e = reply->error();
+    const QString es = reply->errorString();
     reply->deleteLater();
     reply = 0;
     
